@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # To-do list manager.
-# Copyright (C) 2006-2008 MiKael NAVARRO
+# Copyright (C) 2006-2010 MiKael NAVARRO
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #
 
 """yaGTD
-Copyright (C) 2006-2008 MiKael NAVARRO
+Copyright (C) 2006-2010 MiKael NAVARRO
 
 A primitive Getting Things Done to-do list manager.
 
@@ -91,7 +91,7 @@ class Task(Dict):
                    }
 
     # Additional properties from Stephen Covey (cf. Seven Habits of Highly Effective People)
-    properties = { 'urgency': THIS_YEAR,  # urgency (U)
+    properties = { 'urgency': THIS_MONTH,  # urgency (U)
                    'importance': NORMAL,  # importance (I)
                    'time': datetime.timedelta(hours=1),  # time required (T)
                    'complete': 0,                        # percent complete (C)
@@ -177,7 +177,7 @@ class Task(Dict):
 
     #
     # Compute priority of the task:
-    # From Keith Martin (http://96db.com/about.htm) works.
+    # From Keith Martin works.
     #
 
     def _needed_hours(self):
@@ -238,7 +238,10 @@ class Task(Dict):
     def priority(self):
         """Compute priority."""
 
-        I = self['importance']
+        if "someday" in self['status']:
+            I = SOMEDAY  # min importance
+        else:  # == importance (even for !waitingfor)
+            I = self['importance']
 
         #P = min(self['urgency']+2, self._schedule_pressure())
         P = self._schedule_pressure()
