@@ -29,8 +29,8 @@ Cmd version: line oriented command interpreters.
 
 # Specific variables for pydoc
 __author__ = "MiKael Navarro <klnavarro@gmail.com>"
-__date__ = "June 2010"
-__version__ = "0.3.3"
+__date__ = "July 2010"
+__version__ = "0.3.4"
 
 # Include directives
 import os
@@ -508,7 +508,7 @@ class GTD(cmd.Cmd):
 
     def do_add(self, line):
         """Add a new task (from the input line):
-        GTD> add Ny new task. @context p:Project"""
+        GTD> add My new task. @context p:Project"""
 
         task_id = self._add(line)
         if task_id: 
@@ -736,7 +736,7 @@ class GTD(cmd.Cmd):
     #
 
     def do_urgency(self, id_level):
-        """Set the Urgency (5=today,4=this_week,3=this_month,2=this_quarter,1=this_year):
+        """Set the Urgency (5=today, 4=this_week, 3=this_month, 2=this_quarter, 1=this_year):
         GTD> urgency #id lvl"""
 
         # Parse command line
